﻿using Microsoft.Extensions.Logging;
#if WINDOWS
using Microsoft.Maui.LifecycleEvents;
using WinRT.Interop;
using Microsoft.UI;
using Microsoft.UI.Windowing;
#endif

namespace AdventureWorks.MAUI;

public static class MauiProgram
{
  public static MauiApp CreateMauiApp()
  {
    var builder = MauiApp.CreateBuilder();
    builder
      .UseMauiApp<App>()
      .ConfigureFonts(fonts =>
      {
        fonts.AddFont("OpenSans-Regular.ttf", "OpenSansRegular");
        fonts.AddFont("OpenSans-Semibold.ttf", "OpenSansSemibold");
      });

#if WINDOWS
  SetWindowOptions(builder);
#endif

#if DEBUG
    builder.Logging.AddDebug();
#endif

    return builder.Build();
  }

#if WINDOWS
public static void SetWindowOptions(MauiAppBuilder builder)
{
  builder.ConfigureLifecycleEvents(events =>
  {
    events.AddWindows(wndBuilder =>
    {
      wndBuilder.OnWindowCreated(window =>
      {
        IntPtr hndl = WindowNative.GetWindowHandle(window);
        WindowId winId = Win32Interop.GetWindowIdFromWindow(hndl);
        AppWindow appWnd = AppWindow.GetFromWindowId(winId);
        if (appWnd.Presenter is OverlappedPresenter p) {
          p.Maximize();

          //p.HasBorder = false;
          //p.HasTitleBar = false;
          //p.IsAlwaysOnTop = false;
          //p.IsMaximizable = false;
          //p.IsMinimizable = false;
          //p.IsModal = false;
          //p.IsResizable = false;
        }
      });
    });
  });
}
#endif

}
